@@ -33,6 +33,7 @@ from elftools.common.py3compat import bytes2str
 from elftools.elf.elffile import ELFFile
 from elftools.elf.sections import SymbolTableSection
 
+from traceback import format_exc
 
 def about ():
   print 'This is repochecker: binary symbols'
@@ -76,7 +77,8 @@ def gen_config ():
                     'user': 'mysql',
                     'pass': '11111111'
                    },
-                 'package-extensions' : tuple(['.rpm'])})
+                 'package-extensions' : ['.rpm'],
+                 'ignores' : ['-debug-']})
   return config
 
 def save_config (config, filename):
@@ -90,17 +92,27 @@ def save_config (config, filename):
   except Exception, x:
     print '[ERROR] Failed to save config to %s: %s' % (filename, str(x))
 
-def get_packages (repo_path, extensions = ['.rpm']):
+def get_packages (repo_path, extensions = ['.rpm'], excludes = ['-debug-']):
   tree = os.walk (repo_path);
   for root, dirs, files in tree:
     for f in files:
+      ok = False
       # we expect the extensions list to be quite small usually
       for e in extensions:
         if f.endswith (e):
-          yield [root, f]
+          ok = True
+          break
+      if '/log/' in root or root.endswith ('/log'):
+        continue
+      for e in excludes:
+        if e in f:
+          ok = False
+          break
+      if ok:
+        yield [root, f]
 
-def analyze_packages (directory, extensions):
-  for package in get_packages (directory, extensions):
+def analyze_packages (directory, extensions, ignores):
+  for package in get_packages (directory, extensions, ignores):
     fname = os.path.join(package[0], package[1])
     package_name = package[1]
     print '%s...' % package_name,
@@ -152,7 +164,7 @@ def analyze_packages (directory, extensions):
       print '[  OK  ]'
     except Exception, e:
       print '[ FAIL ]'
-      logger.error(fname, str(e))
+      logger.error(fname, str(e) + format_exc(e))
 
 def process_repository (repo_info):
   """
@@ -167,29 +179,34 @@ def process_repository (repo_info):
   start = datetime.datetime.now()
   d = repo_info ['repository']
   storage.init(repo_info ['db'])
+  logger.init(repo_info)
   if not os.path.isdir(d):
     print 'ERROR: repository %s does not exist (directory not found)' % d
     return
-  analyze_packages(d, repo_info ['package-extensions'])
+  analyze_packages(d, repo_info ['package-extensions'], repo_info ['ignores'])
   analyzed = datetime.datetime.now()
   verdict = storage.find_unresolved()
-  logger.init(repo_info)
   if verdict != {}:
-    for package, details in verdict.iteritems():
-      logger.log_package_details (package, details)
-  logger.commit()
+    prev_pack = verdict[0][0]
+    missing_symbols = []
+    for package, details in verdict:
+      if package == prev_pack:
+        missing_symbols.append(str(details))
+      else:
+        logger.log_package_details (str(prev_pack), missing_symbols)
+        missing_symbols = [str(details)]
+        prev_pack = package
   dependencies_found = datetime.datetime.now()
-  storage.commit()
   data_saved = datetime.datetime.now()
 
   print
   print '*** READY ***'
-  total_delta = data_saved - start
-  delta1 = analyzed - start
-  print 'Analysis took', delta1, '%.2f%%' % (100.* delta1.seconds / total_delta.seconds)
-  delta1 = dependencies_found - analyzed
-  print 'Dependency calculation took', delta1, '%.2f%%' % (100. * delta1.seconds / total_delta.seconds)
-  delta1 = data_saved - dependencies_found
-  print 'DB write took', delta1, '%.2f%%' % (100. * delta1.seconds / total_delta.seconds)
+  total_delta = (data_saved - start).total_seconds()
+  delta1 = (analyzed - start).total_seconds()
+  print 'Analysis took %.4f s,' % delta1, '%.2f%%' % (100.* delta1 / total_delta)
+  delta1 = (dependencies_found - analyzed).total_seconds()
+  print 'Dependency calculation took %.4f s,' % delta1, '%.2f%%' % (100. * delta1 / total_delta)
+  delta1 = (data_saved - dependencies_found).total_seconds()
+  print 'DB write took %.4f s,' % delta1, '%.2f%%' % (100. * delta1 / total_delta)
   print
-  print 'Overall working time:', total_delta
+  print 'Overall working time: %.4f s,' % total_delta
